'use strict';

const gulp = require('gulp');
const jetpack = require('fs-jetpack');
const bundle = require('./bundle');
const istanbul = require('rollup-plugin-istanbul');

const createEntryFile = async(srcDir, matching, outputDir, entryFileName, rollupOptions) => {
	const entryFileContent = srcDir.find('.', { matching })
		.map((path) => `import './${ path.replace(/\\/g, '/') }';`)
		.join('\n');

	srcDir.write(entryFileName, entryFileContent);

	await bundle(srcDir.path(entryFileName), outputDir.path(entryFileName), rollupOptions);

	srcDir.remove(entryFileName);
};

gulp.task('build-unit-tests', ['environment'], () => createEntryFile(
	jetpack.cwd('src'), '*.spec.js',
	jetpack.cwd('app'), 'specs.js.autogenerated',
	{
		rollupPlugins: [
			istanbul({
				exclude: ['**/*.spec.js', '**/specs.js.autogenerated'],
				sourcemap: true,
			}),
		],
	}
));

gulp.task('build-e2e-tests', ['build-app'], () => createEntryFile(
	jetpack.cwd('src'), '*.e2e.js',
	jetpack.cwd('app'), 'e2e.js.autogenerated'
));
